<?php
/**
 * OOPでBBS (Step8)
 *
 * オブジェクト指向プログラミングで掲示板を作ってみる。
 * ブログでその作り方を晒すために書いたものです。
 * 詳しい事は当該記事を見てください。 
 *
 *
 *           
 * PHP version 5.3
 *
 * LICENSE : このソースはCreative Commons 表示 - 非営利 2.1 日本 Licenseです。
 *           改変は自由ですが営利目的で利用することは出来ません。
 *
 * @category  Step8
 * @package   OOPdeBBS
 * @author    Tenderfeel <tenderfeel@gmail.com>
 * @copyright Copyright (c) 2010 Tenderfeel.(http://webtecnote.com)
 * @license   http://creativecommons.org/licenses/by-nc/2.1/jp/
 * @since     File available since Release 1.0.0 (step1)
 *
 */
 

/**
 * 掲示板の描画を行うクラス
 *
 * ViewはControllerに使役されるクラスです。
 * 掲示板の表示を受け持ちます。
 *
 * <step8>
 * setLogdata、getLogdataをset、getメソッドに変更。set/getメソッドは$viewVarsへ値を保存します。
 * $viewVarsはdisplay内でextractを使って変数化。テンプレートで使える変数の自由度がひろがりんぐ。
 * $logdataの場合は $this->view->set('logdata', $this->model->getLogData())になります。
 * テンプレート読み込み前にob_startしてバッファに保存。あとで一気に放出。
 * コメントアウトしていたソースを削除した。
 * 
 * @author    Tenderfeel <tenderfeel@gmail.com>
 * @copyright Copyright (c) 2010 Tenderfeel.(http://webtecnote.com)
 * @license   Creative Commons BY-NC http://creativecommons.org/licenses/by-nc/2.1/jp/
 * @since     File available since Release 1.0.0 (step1)
 */
class View {
    
    private $_templateDirectory; //テンプレートディレクトリ
    private $_templateName;      //テンプレートファイル名
	private $_tempateExtention;  //テンプレートの拡張子
    private $_systemMessage;     //システムメッセージ
	protected $_userControll;      //ユーザー操作許可
    private $viewVars = array(); //ビューに渡すプロパティ
    
    public function __construct($config)
    {
		$this->_templateDirectory = $config->get('template_directory') . DIRECTORY_SEPARATOR;
		$this->_templateExtention = '.' . $config->get('template_extention');
        $this->_templateName = '';
        $this->_systemMessage = array('type'=>'', 'text'=>'');
		
		if($config->get('user_controll')==='1'){//ユーザーによる操作
			$this->_userControll = true;
		}
        
        $this->set('token', $this->createToken());//トークン
    }
    
     /**
     * テンプレート名のセッター
     * @param {string}  $name テンプレートファイル名
     * @return {}
     * @since 1.2 (step2)
     */
    public function setTemplateName($name)
    {
        $this->_templateName = $name . $this->_templateExtention;
    }
    
    /**
     * テンプレート名のゲッター
     * @return {string}　テンプレートファイル名
     * @since 1.2 (step2)
     */
    public function getTemplateName()
    {
       return  $this->_templateDirectory . $this->_templateName;
    }
    
    /**
     * システムメッセージのセッター
     * @param {NULL|string} $type メッセージのタイプ
     * @param {string} $text メッセージ文字列
     * @return {}
     * @since 1.2(step2)
     */
    public function setSystemMessage($type=NULL, $text)
    {
        $this->_systemMessage = array('type'=>$type, 'text'=>$text);
    }
    
    /**
     * システムメッセージのゲッター
     * @return array|string メッセージ配列または文字列
     * @since Version 1.2 (step2)
     */
    public function getSystemMessage()
    {
        return $this->_systemMessage['text'];
    }
    
    /**
     * プロパティセッター
     * @param {string} $property プロパティ名
     * @param {mixed} $value セットする値
     * @return {}
     * @since 1.8(Step8)
     */
     
    public function set($property, $value)
    {
        $this->viewVars[$property] = $value;
    }
    
    /**
     * プロパティのゲッター
     * @return {array} $property プロパティ名
     * @since 1.8(Step8)
     */
    public function get($property)
    {
        return $this->viewVars[$property];
    }
    
    /**
     * トークンの作成
     * @return {string} ランダムな半角英数から成る文字列
     * @since 1.5(Step5)
     */
    public function createToken()
    {
        return substr(sha1(uniqid().mt_rand()),-13,10);
    }
    
    /**
     * ページネーション
     * @param array $params　ページ番号・最大ページ数・データ件数・表示件数
     */
    public function paginate($params)
    {
        include('pagination.php');
        $this->set('pagination', new Pagination($params));
    }
	
    /**
     * 画面に表示する
     * @return
     * @since 1.0 (step1)
     */
    public function display()
    {
        $class = empty($this->_systemMessage['type']) ? '' : ' ' . $this->_systemMessage['type'];
        $message = $this->getSystemMessage();
       
        if(isset($message)){
            if( is_array($message) ){
               $message = implode('<br />', $message);
            }
            
            $message = '<p class="message' . $class . '">' . $message . '</p>';
        }
        
        extract($this->viewVars);
        
        ob_start();
        include($this->getTemplateName());
        echo ob_get_clean();
    }
}

?>